# ETTJ

Convert excel table to json file. I've found this usefull to validate data in my database and i've got only xlsx table.
---

## Instalation
>pypi.org soon
## How to use?
Program takes a few arguments:
### positional arguments:
- excel_file_path
> Path to a excel file with table.
- output_path
> Path you want to save a json file.

### options:
- -h, --help
> Show help message and exit
